@@ -9,9 +9,9 @@ function(cases, controls) {
 	## and L_i be the label (genome location) at the ith distinct read position
 	cases = sort(cases)
 	controls = sort(controls)
-	combCC = .Call("CombineSortedVectorC", as.numeric(cases), as.numeric(controls), PACKAGE="seqCBS")
-	combL = .Call("FindUniqueInSortedArrayC", as.numeric(combCC), PACKAGE="seqCBS")
-	combZX = .Call("CombineToUniqueValueC", as.numeric(cases), as.numeric(controls), as.numeric(combL), PACKAGE="seqCBS")
+	combCC = .Call(C_CombineSortedVectorC, as.numeric(cases), as.numeric(controls))
+	combL = .Call(C_FindUniqueInSortedArrayC, as.numeric(combCC))
+	combZX = .Call(C_CombineToUniqueValueC, as.numeric(cases), as.numeric(controls), as.numeric(combL))
 	combZ = as.numeric(combZX[,1])
 	combX = as.numeric(combZX[,2])
 	return(list(combX=combX, combZ=combZ, combL=combL))
