@@ -5,6 +5,8 @@
 #include <R_ext/Print.h>
 #include <Rmath.h>
 #include <math.h>
+#include <stdlib.h>
+#include <R_ext/Rdynload.h>
 
 /*
 # CombineSortedVectorC.c
@@ -13,12 +15,6 @@
 # Updated: 4/13/2010
 */
 
-#include <R.h>
-#include <Rinternals.h>
-#include <Rdefines.h>
-#include <R_ext/Print.h>
-#include <math.h>
-
 SEXP CombineSortedVectorC(SEXP casesS, SEXP controlsS) {
 	double *cases = REAL(casesS);
 	double *controls = REAL(controlsS);
@@ -149,7 +145,7 @@ SEXP ScanStatNewCompBinomC(SEXP combZCumSumS, SEXP combXCumSumS, SEXP combZPoint
 	double *gridCur = REAL(gridCurS);
 	double maxWin = REAL(maxWinS)[0];
 	long long i, j, jMax, bestWinI, bestWinJ;
-	double nCas, nObs, nCon, pNObs, nCasTot, nConTot, nCasOut, nConOut, pOut, Rij, bestWinR, pij, l0;
+	double nCas, nObs, nCon, nCasTot, nConTot, nCasOut, nConOut, pOut, Rij, bestWinR, pij, l0;
 	SEXP newRes;
 	PROTECT(newRes = allocMatrix(REALSXP, gridCurMaxInd, 3));
 	double *newResPtr = REAL(newRes);
@@ -250,7 +246,7 @@ SEXP ScanStatRefineCompBinomC(SEXP combZCumSumS, SEXP combXCumSumS, SEXP combZPo
 	double maxWin = REAL(maxWinS)[0];
 	double jMin, gridLL, gridLR, gridRL, gridRR;
 	long long i, j, nRows, bestWinI, bestWinJ, rCt;
-	double nCas, nObs, nCon, pNObs, nCasTot, nConTot, nCasOut, nConOut, nTotOut, pOut, Rij, bestWinR, pij, l0;
+	double nCas, nObs, nCon, nCasTot, nConTot, nCasOut, nConOut, pOut, Rij, bestWinR, pij, l0;
 	int newIter;
 	
 	nCasTot = combZCumSum[length(combZCumSumS)-1];
@@ -750,3 +746,28 @@ SEXP BayesCptCICompC(SEXP betaParam1S, SEXP betaParam2S, SEXP wksS, SEXP alphaS,
 	UNPROTECT(1);
 	return(CI);
 }
+
+#define CALLDEF(name, n)  {#name, (DL_FUNC) &name, n}
+static const R_CallMethodDef R_CallDef[] = {
+   CALLDEF(BayesCptCICompC, 5),
+   CALLDEF(CombineSortedVectorC, 2),
+   CALLDEF(CombineToUniqueValueC, 3),
+   CALLDEF(dBetaMixEval, 5),
+   CALLDEF(FindUniqueInSortedArrayC, 1),
+   CALLDEF(pBetaMixRootEval, 6),
+   CALLDEF(rtBetaMixCDF, 6),
+   CALLDEF(ScanIGSGridCumSumC, 2),
+   CALLDEF(ScanStatNewCompBinomC, 8),
+   CALLDEF(ScanStatNewCompNormalC, 9),
+   CALLDEF(ScanStatNewCompRabinC, 9),
+   CALLDEF(ScanStatRefineCompBinomC, 9),
+   CALLDEF(ScanStatRefineCompNormalC, 10),
+   CALLDEF(ScanStatRefineCompRabinC, 10),
+   {NULL, NULL, 0}
+};
+
+void R_init_seqCBS(DllInfo *dll)
+{
+    R_registerRoutines(dll, NULL, R_CallDef, NULL, NULL);
+    R_useDynamicSymbols(dll, FALSE);
+}
